<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2006, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sourceforge.net>
	*	@link		http://www.gekkoware.org
	*/

	if (!defined("IN-GEKKO")) die("Get a life!");

	loadLib (
		"feeder.lib.php",
		"blog",
		"categories",
		"comments",
		"users"
	);

	// This is a URL prototype, below you can specify the way you want to load your variables
	extract (
		URLGetArgs('/null/action=alpha/type=string?id=int&page=page&cpage=page&user=alpha&category=string&date=date&path=string&full=int')
	);

	// Setting default values when no ones were met for variables below

	switch ($action) {

		case "feed": {

			define ("GEKKO_USE_ABSOLUTE_URLS", true);

			if (!$type)
				$type = "rss";

			if ($category)
				$category = categories::getID($category);

			if ($user)
				$author_id = users::getID($user);

			if (!$user || $author_id) {

				// removing extension
				$type = preg_replace("/\..*/", "", $type);

				// creating feeder
				$feed = new XMLFeed($type);

				$categoryLock = categories::db_categorylock("category_id", null, "*");
				$categoryMatch = categories::db_match($category);

				// main query
				$q = $db->query ("
				SELECT
					id, author_id, category_id, title, content, date_created
				FROM ".db_table("blog")."
				WHERE ".db_languagelock()." AND status = '1'
				".(isset($author_id) ? "AND author_id='{$author_id}' " : "")."
				AND {$categoryLock} AND {$categoryMatch}
				ORDER BY date_created ".($full ? "": "DESC LIMIT ".conf::getkey('blog', 'feed_items', 30, 'i'))."
				", __FILE__, __LINE__);

				// adding each listed item
				if ($db->numRows($q)) {
					while ($row = $db->fetchRow($q)) {
						// filtering html according user privileges
						format::style($row["content"], $row["author_id"]);

						$row["CATEGORY"] = cacheFunc("categories::getCategory", $row["category_id"], true);
						$row["LINK"] = urlEvalPrototype("index.php/module=blog/action=view/title=".urlTitleEncode($row["title"])."?id={$row["id"]}");
						$row["PERMALINK"] = urlEvalPrototype("index.php/module=blog/action=permalink?path={$row["id"]}.".date2time($row["date_created"]));
						$row["COMMENTS"] = urlEvalPrototype("index.php/module=blog/action=view/title=".urlTitleEncode($row["title"])."?id={$row["id"]}#comment");

						$feed->addItem($row);
					}
					// that's all folks! (outputting buffer and closing connections)
					$feed->serve($type);
					shutdown();
				}
			}

			header("Location: index.php");
			shutdown();
			break;
		}
		case "permalink":
			preg_match("/(\d*).(\d*)/", $path, $match);

			if (isset($match[2])) {

				list($buff, $id, $creationtime) = $match;
				unset($match);

				$q = $db->query("SELECT title FROM ".db_table("blog")." WHERE id = '{$id}' AND
				date_created = FROM_UNIXTIME('$creationtime')", __FILE__, __LINE__);

				if ($db->numRows($q)) {
					$row = $db->fetchRow($q);
					redirect("index.php/module=blog/action=view/title=".urlTitleEncode($row["title"])."?id={$id}");
				} else {
					redirect("index.php/module=blog?message=".urlencode(_l("L_UNKNOWN_PERMALINK"))."&type=error");
				}

			} else {
				redirect("index.php/module=blog");
			}
			shutdown();
		break;
		case "view":

			// querying for blog entry
			$db->query("
				SELECT
				id, author_id, category_id, icon, title, content, footer, date_created,
				allow_comments
				FROM ".db_table("blog")." WHERE ".db_languagelock()." AND status = '1' AND id='{$id}'
			", __FILE__, __LINE__);

			// dows this entry exists?
			if ($db->numRows()) {

				// creating content block
				$tpl = new ContentBlock();
				$tpl->load("blog/main.view.tpl");

				$row = $db->fetchRow();

				// is the user allowed to see topics under this category?
				if (categories::auth($row["category_id"])) {

					// sanitising all variables but 'content' and 'footer'
					saneHTML($row, "content,footer");

					// filtering remaining variables according to author's privileges
					format::style($row["content"], $row["author_id"]);
					format::style($row["footer"], $row["author_id"]);

					// don't want this to be a link to itself
					$row["title_link"] = $row["title"];

					// setting variables in content-block's schema
					$tpl->setArray($row);

					// modifying block variables
					$tpl->setArray (
						Array (
							"CATEGORY_TITLE"	=> categories::getCategory($row["category_id"]),
							"PERMALINK"			=> blog::createPermalink($row),
							"PAGE"				=> $page
						)
					);

					// compiling template,
					$mcBuff = $tpl->make();

					// setting main page's title to this item's title since it's the
					// most important displayed information
					pageSetTitle($row["title"]);

					blog::countRead($id);

				} else {
					$mcBuff = AccessDenied();
				}
			break;
		}
		default:

			// for listing post within the allowed time, 'date_created'
			$datelock = db_datelock("date_created", $date);

			// allowed categories only
			$categorylock = categories::db_categorylock("category_id", $category);

			// creating the pager
			$pager = $db->pager (
				"SELECT id FROM ".db_table("blog")."
				WHERE ".db_languagelock()." AND status = '1' AND {$datelock} AND {$categorylock}",
				"index.php/module=blog?page=%p".($category ? "&category=".urlTitleEncode($category) : ""), $page,
				conf::getkey("blog", "items_per_page")
			);

			// main query
			$db->query ("
			SELECT
				id, author_id, category_id, icon, title, content, footer, date_created,
				allow_comments
			FROM ".db_table("blog")."
			WHERE status = '1' AND {$datelock} AND {$categorylock}
			ORDER BY date_created DESC {$pager['sql']}
			", __FILE__, __LINE__);

			if ($db->numRows()) {

				$tpl = new ContentBlock();
				$tpl->load("blog/main.default.tpl");

				while ($row = $db->fetchRow()) {

					// cleaning html for all items but 'content' and 'footer'
					saneHTML($row, "content,footer");

					// html filtering according user's privileges
					format::introStyle($row["content"], $row["author_id"]);
					format::style($row["footer"], $row["author_id"]);

					// cacheing common variables
					$category_title = cacheFunc("categories::getCategory", $row["category_id"], true);

					$row["title_link"] = mkLink("index.php/module=blog/action=permalink?path={$row["id"]}.".date2time($row["date_created"]), $row["title"]);

					$tpl->setArray($row, "POST");

					// variables passed to block's scheme
					$tpl->setArray (
						Array (
							"CATEGORY_TITLE"	=> mkLink("index.php/module=blog?category=".urlTitleEncode($category_title), $category_title),
							"PERMALINK"			=> blog::createPermalink($row)
						),
						"POST"
					);

					// compiling template.
					$tpl->saveBlock("POST")."\n";
				}

				$tpl->setArray (
					Array (
						"PAGER"	=> $pager["html"]
					)
				);

				$mcBuff = $tpl->make();

				// attaching link for RSS feeders.
				pageSetMarkContent("HEAD", '<link rel="alternate" type="application/rss+xml" title="'._l("C_SITE.TITLE").'" href="'._l("C_SITE.URL").'index.php/blog/feed/rss.xml" />');

				// attaching nice XML buttons at page's footer.
				pageSetMarkContent("FOOTER", mkFeederButtons("index.php/module=blog/action=feed/type=%s".($category ? "?category=".str_replace("%", "%%", urlTitleEncode($category)) :"")));

			}
		break;
	}
?>