<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2006, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sourceforge.net>
	*	@link		http://www.gekkoware.org
	*/

	define ("IN-GEKKO", true);

	require_once "../../conf.php";

	LoadLib (
		"file.lib.php",
		"image.lib.php",
		"categories"
	);

	db_init();

	require_once GEKKO_SOURCE_DIR."lib/auth.inc.php";

	varImport("action", "id", "return");

	if (is_admin()) {
		// administrative tasks
		switch ($action) {
			case "delete":
				execWithEach($id, "categories::deleteItem");
				slog("categories: deleted category id =(".(is_array($id) ? implode(",", $id) : $id).")");
			break;
			case "disable":
				categories::setItemStatus($id, 0);
				slog("categories: disabled category id='$id'");
			break;
			case "enable":
				categories::setItemStatus($id, 1);
				slog("categories: enabled category id='$id'");
			break;
			case "create":

				varImport ("icon", "title", "description", "status", "auth_access", "tags");

				varRequire ("title");

				// custom icon?
				if ($_POST["remote_file"] || $_FILES["local_file"]["size"]) {
					// getting file from path (if it was uploaded) or by url
					$thumb = file_get("local_file", "remote_file");
					if ($thumb) {
						$thumb = mkthumbnail($thumb["abs_loc"], "50x50");
						$icon = $thumb["url"];
					}
				}

				// checking for duplicated category name
				$q = $db->query ("SELECT id
					FROM ".db_table("category")."
					WHERE title = '{$title}'",
				__FILE__, __LINE__);

				// there is another category with that name!
				if ($db->numRows($q))
					fromInputError("{E_DUPLICATED_ENTRY}", "focus: title");

				// new categorie's id
				$category_id = $db->findFreeId("category");

				// checking for tags that already exists
				$tags = explode(",", $tags);
				$done = Array();
				foreach ($tags as $tag) {
					$tag = trim($tag);
					if ($tag && !isset($done[strtolower($tag)])) {
						categories::tagInsert($tag, $category_id);
						$done[strtolower($tag)] = true;
					}
				}

				// inserting new category into database
				$db->query ("
				INSERT INTO ".db_table("category")."
					(
						id,
						icon,
						title,
						description,
						status,
						date_created,
						auth_access
					)
						VALUES
					(
						'{$category_id}',
						'{$icon}',
						'{$title}',
						'{$description}',
						'{$status}',
						CURRENT_TIMESTAMP(),
						'".groups::extractFromInput($auth_access)."'
					)
				", __FILE__, __LINE__);

				slog("categories: created category '$title'");
			break;
			case "edit":

				varImport ("icon", "title", "description", "status", "auth_access", "tags");

				varRequire ("id", "title");

				// another icon specified?
				if ($_POST["remote_file"] || $_FILES["local_file"]["size"]) {
					$thumb = file_get("local_file", "remote_file");

					if ($thumb) {
						// creating a new icon
						$thumb = mkthumbnail($thumb["abs_loc"], "50x50");
						$icon = $thumb["url"];

						// deleting old icon
						$orig = db_get_field("category", $id, "icon");
						if (file_exists($opath = GEKKO_USER_DIR.$orig)) {
							@unlink($opath);
						}
					}
				}

				// reorganizing tags
				$original_tags = categories::categoryGetTags($id, false);

				$delete = $create = array();
				foreach ($original_tags as $tag)
					$delete[strtolower($tag)] = true;

				$tags = explode(",", $tags);
				foreach ($tags as $tag) {
					$tag = trim($tag);
					if (isset($delete[strtolower($tag)])) {
						// keeping this tag where it is
						$delete[strtolower($tag)] = false;
					} else {
						// inserting a new tag or updating category
						categories::tagInsert($tag, $id);
					}
				}

				// getting rid of tags that were removed from the list
				foreach ($delete as $tag => $doit) {
					if ($doit)
						categories::tagDelete($tag);
				}

				// updating category information
				$db->query ("
					UPDATE ".db_table("category")." SET
						icon = '{$icon}',
						title = '{$title}',
						description = '{$description}',
						status = '{$status}',
						auth_access = '".groups::extractFromInput($auth_access)."'
					WHERE id = '{$id}'
				", __FILE__, __LINE__);

				slog("categories: updated category '$title' (id='$id')");

			break;
		}
	}

	redirect($return);

	db_exit();
?>